@@ -7,7 +7,7 @@ class Timer:
         s = int(s)
         for i in range(s):
             print(s - i)
-            time.sleep(s)
+            time.sleep(1)
         print(0)    
 
     def sleep(s):
